@@ -48,7 +48,7 @@ G_BEGIN_DECLS
 #define LIBBRASERO_MEDIA_AGE							\
 	332
 #define LIBBRASERO_MEDIA_INSTALL							\
-	"/usr"
+	"/home/mclasen/gnome"
 
 /**
  * To start and stop the library
